@@ -42,6 +42,7 @@ public:
         AutoSaveAfterEveryChange,
         AutoReloadOnChange,
         AutoSaveOnExit,
+        AutoSaveNonDataChanges,
         BackupBeforeSave,
         UseAtomicSaves,
         SearchLimitGroup,
@@ -57,7 +58,6 @@ public:
         AutoTypeStartDelay,
         GlobalAutoTypeKey,
         GlobalAutoTypeModifiers,
-        TrackNonDataChanges,
         FaviconDownloadTimeout,
         UpdateCheckMessageShown,
         UseTouchID,
